@@ -26,7 +26,7 @@ import urllib.parse
 
 from io import StringIO
 
-from onionprobe.config import OnionprobeConfigCompiler, basepath
+from onionprobe.config import OnionprobeConfigCompiler, basepath, cmdline_parser_compiler, cmdline_compiler
 
 try:
     import requests
@@ -60,20 +60,30 @@ class SecureDropSites(OnionprobeConfigCompiler):
 
         """
 
-        # Get the Onion Service database from a remote API
-        try:
-            print('Fetching remote list of %s database endpoints...' % (database))
+        endpoints = {}
 
-            result    = requests.get(self.databases[database])
-            data      = json.load(StringIO(result.text))
-            endpoints = {}
+        # Get the Onion Service database from API data
+        if os.path.exists(self.databases[database]):
+            print('Using list of %s database endpoints from %s...' % (
+                database, self.databases[database]))
 
-        except Exception as e:
-            # Log the exception
-            print(repr(e))
+            with open(self.databases[database], 'r') as result:
+                data = json.loads(result.readlines()[0])
 
-            # Some error happened: do not proceed generating the config
-            exit(1)
+        else:
+            try:
+                print('Fetching remote list of %s database endpoints from %s...' % (database, self.databases[database]))
+
+                result    = requests.get(self.databases[database])
+                data      = json.load(StringIO(result.text))
+                endpoints = {}
+
+            except Exception as e:
+                # Log the exception
+                print(repr(e))
+
+                # Some error happened: do not proceed generating the config
+                exit(1)
 
         # Parse the database and convert it to the Onionprobe endpoints format
         for item in data:
@@ -115,18 +125,11 @@ class SecureDropSites(OnionprobeConfigCompiler):
 if __name__ == "__main__":
     """Process from CLI"""
 
-    # Check if a template file is provided, overriding the default location
-    if len(sys.argv) > 1 and os.path.exists(sys.argv[1]):
-        template_config = sys.argv[1]
-    else:
-        template_config = None
+    args = cmdline_compiler(databases['securedrop'])
 
-    # Check if an output path is provided, overriding the default location
-    if len(sys.argv) > 2:
-        output_path = sys.argv[2]
-    else:
-        output_path = None
+    if args.source != None:
+        databases['securedrop'] = args.source
 
-    instance = SecureDropSites(databases, template_config, output_path)
+    instance = SecureDropSites(databases, args.config_template, args.output_folder)
 
     instance.build_onionprobe_config()
